@@ -2024,6 +2024,19 @@ class ContentEvent:
         self.document_family: DocumentFamily = document_family
         """The document family containing the content object"""
 
+    @classmethod
+    def from_dict(cls, event_dict: dict):
+        return ContentEvent(ContentObject.from_dict(event_dict['contentObject']),
+                            ContentEventType[event_dict['eventType']],
+                            DocumentFamily.from_dict(event_dict['documentFamily']))
+
+    def to_dict(self):
+        return {
+            'contentObject': self.content_object.to_dict(),
+            'documentFamily': self.document_family.to_dict(),
+            'eventType': self.event_type
+        }
+
 
 class DocumentActor:
     """A document actor is something that can create a new document in a family and is
@@ -2085,6 +2098,19 @@ class DocumentTransition:
                                         transition_dict['destinationContentObjectId'])
         return transition
 
+    def to_dict(self) -> dict:
+        """
+        Convert the transition to a dictionary to match REST API
+
+        Returns:
+            dictionary of transition
+        """
+        return {
+            'transitionType': self.transition_type,
+            'sourceContentObjectId': self.source_content_object_id,
+            'destinationContentObjectId': self.destination_content_object_id
+        }
+
 
 class DocumentFamily:
     """A document family represents a collection of related documents which together represent different views of the same
@@ -2117,7 +2143,7 @@ class DocumentFamily:
           transition: DocumentTransition:  (Default value = None)
 
         Returns:
-
+          A new content event
         """
         new_content_object = ContentObject()
         new_content_object.store_ref = self.store_ref
@@ -2182,6 +2208,20 @@ class DocumentFamily:
             document_family.transitions.append(DocumentTransition.from_dict(transition_dict))
         return document_family
 
+    def to_dict(self) -> dict:
+        """
+        Convert the document family to a dictionary to match REST API
+
+        Returns:
+            dictionary of document family
+        """
+        return {
+            'id': self.id,
+            'storeRef': self.store_ref,
+            'path': self.path,
+            'contentObjects': [co.to_dict() for co in self.content_objects],
+            'transitions': [transition.to_dict() for transition in self.transitions]}
+
 
 class DocumentStore:
     """
@@ -2213,6 +2253,20 @@ class DocumentStore:
         """
         raise NotImplementedError
 
+    @abc.abstractmethod
+    def get_family(self, document_family_id: str) -> Optional[DocumentFamily]:
+        """
+        Returns a document family based on the ID
+
+        Args:
+            document_family_id (str): the ID of the document family
+
+        Returns:
+            The document family (or None if not found)
+
+        """
+        raise NotImplementedError
+
     @abc.abstractmethod
     def delete(self, path: str):
         """
