@@ -1,4 +1,7 @@
-from kodexa import Assistant, AssistantContext, AssistantResponse, ContentEvent, Pipeline
+from kodexa.assistant import Assistant, AssistantContext, AssistantResponse
+from kodexa.assistant.assistant import AssistantPipeline
+from kodexa.model import ContentEvent
+from kodexa.pipeline import Pipeline
 
 
 class TestAction:
@@ -32,4 +35,4 @@ class TestAssistant(Assistant):
         pipeline = Pipeline()
         pipeline.add_label('hello')
 
-        return AssistantResponse([pipeline])
+        return AssistantResponse([AssistantPipeline(pipeline)])
