@@ -3,10 +3,12 @@ import importlib
 import logging
 from typing import List, cast
 
-from addict import Dict, addict
+from addict import addict
 
 from kodexa import Assistant, AssistantResponse, LocalDocumentStore
-from kodexa import ContentNode, Document, PipelineContext, TableDataStore,  ContentEvent, DocumentActor, DocumentTransition, TransitionType
+from kodexa import ContentEvent, ContentNode, Document, DocumentActor, DocumentTransition, PipelineContext, \
+    TableDataStore, TransitionType
+from kodexa.assistant.assistant import AssistantMetadata
 from kodexa.model.model import DocumentStore
 
 logger = logging.getLogger('kodexa.testing')
@@ -16,11 +18,8 @@ def print_data_table(context: PipelineContext, store_name: str):
     """A small helper to support working with a store in a test
 
     Args:
-      context: param store_name:
-      context: PipelineContext:
-      store_name: str:
-
-    Returns:
+      context: PipelineContext: The context for the pipeline
+      store_name: str: The store name
 
     """
     if store_name in context.get_store_names():
@@ -74,7 +73,7 @@ def simplify_node(node: ContentNode):
     }
 
 
-def simplify_document(document: Document) -> Dict:
+def simplify_document(document: Document) -> dict:
     """
 
     Args:
@@ -221,43 +220,50 @@ class AssistantTestHarness:
 
     """
 
-    def __init__(self, assistant: Assistant, stores: List[DocumentStore]):
+    def __init__(self, assistant: Assistant, stores: List[DocumentStore], kodexa_metadata_path: str,
+                 metadata: AssistantMetadata):
         """
         Initialize the test harness
 
         Args:
             assistant: the instance of the assistant
             stores: the list of stores (usually LocalDocumentStore) that we will use to monitor for events
+            kodexa_metadata_path (str): the path to the kodexa.yml (or kodexa.json)
+            metadata (AssistantMetadata): the assistant metadata to use for this assistant
         """
         self.assistant = assistant
         self.stores = stores
+        self.kodexa_metadata_path = kodexa_metadata_path
+        self.metadata = metadata
 
         for store in self.stores:
             store.register_listener(self)
 
     def process_event(self, event: ContentEvent):
-        """The harnesss will take the content event and
+        """The harness will take the content event and
         will pass it to the assistant - then we will
         take each of the pipelines and run the document
         through them in turn (note in the platform this might be in parallel)
 
         Args:
-          event: content event
-          event: ContentEvent:
+          event: ContentEvent: The event to process
 
         Returns:
           None
 
         """
+        from kodexa import AssistantContext
+        assistant_context = AssistantContext(self.metadata, self.kodexa_metadata_path)
 
-        response: AssistantResponse = self.assistant.process_event(event)
+        response: AssistantResponse = self.assistant.process_event(event, assistant_context)
 
         # We need to get the document down
         store = self.get_store(event)
 
-        for pipeline in response.pipelines:
+        for assistant_pipeline in response.pipelines:
             document = store.get_document_by_content_object(event.document_family, event.content_object)
             if document is not None:
+                pipeline = assistant_pipeline.pipeline
                 pipeline.connector = [document]
                 pipeline_context = pipeline.run()
 
@@ -329,17 +335,24 @@ class ExtensionPackUtil:
     def __init__(self, file_path='kodexa.yml'):
         self.file_path = file_path
 
-        import yaml
+        if file_path.endswith('.yml'):
+            import yaml
 
-        with open(file_path, 'r') as stream:
-            self.kodexa_metadata = addict.Dict(yaml.safe_load(stream))
+            with open(file_path, 'r') as stream:
+                self.kodexa_metadata = addict.Dict(yaml.safe_load(stream))
+
+        if file_path.endswith('.json'):
+            import json
+
+            with open(file_path, 'r') as stream:
+                self.kodexa_metadata = addict.Dict(json.load(stream))
 
     def get_step(self, action_slug, options=None):
         """
 
         Args:
-          action_slug:
-          options:  (Default value = None)
+          action_slug (str): the slug to the action (ie. pdf-parser)
+          options (dict):  the options for the action as a dictionary (Default value = None)
 
         Returns:
 
@@ -362,7 +375,16 @@ class ExtensionPackUtil:
 
                     for option_name in options.keys():
                         if option_name not in option_names:
-                            raise OptionException(f"Unexpected option {option_name}")
+
+                            # We need to determine if this is actually a group
+                            is_group = False
+                            for check_option in service.metadata.options:
+                                if check_option['group'] is not None:
+                                    if check_option['group']['name'] == option_name:
+                                        is_group = True
+
+                            if not is_group:
+                                raise OptionException(f"Unexpected option {option_name}")
 
                 # We need to create and return our action
                 module = importlib.import_module(service.step.package)
@@ -371,14 +393,15 @@ class ExtensionPackUtil:
 
         raise Exception("Unable to find the action " + action_slug)
 
-    def get_assistant_test_harness(self, assistant_slug, options=None, stores=None) -> AssistantTestHarness:
+    def get_assistant_test_harness(self, assistant_slug, assistant_metadata: AssistantMetadata, options=None, stores=None) -> AssistantTestHarness:
         """Provides a local test harness that can be used to validate the functionality
         of an assistant in a test case
 
         Args:
-          assistant_slug: param options:
-          stores: a list of the document stores to monitor (Default value = None)
-          options:  (Default value = None)
+          assistant_slug (str): The slug for the assistant (ie. pdf-parser-assistant)
+          assistant_metadata (AssistantMetadata): the metadata to use for the assistant
+          stores (List): a list of the document stores to monitor (Default value = None)
+          options (dict): The options to provide  (Default value = None)
 
         Returns:
           The assistant test harness
@@ -388,7 +411,7 @@ class ExtensionPackUtil:
             stores = []
         assistant = self.get_assistant(assistant_slug, options)
 
-        return AssistantTestHarness(assistant, stores)
+        return AssistantTestHarness(assistant, stores, self.file_path, assistant_metadata)
 
     def get_assistant(self, assistant_slug, options=None):
         """Create an instance of an assistant from the kodexa metadata
